from datetime import datetime
from app import db


class Submission(db.Model):
    __tablename__ = 'submissions'

    id = db.Column(db.Integer, primary_key=True)
    user_id = db.Column(db.Integer, db.ForeignKey('users.id'), nullable=False)
    plant_id = db.Column(db.Integer, db.ForeignKey('plants.id'), nullable=True)

    common_name = db.Column(db.String(120), nullable=False)
    scientific_name = db.Column(db.String(120))
    price = db.Column(db.Float, nullable=False)
    source = db.Column(db.String(120))
    timestamp = db.Column(db.DateTime, default=datetime.utcnow)

    height = db.Column(db.Float)
    width = db.Column(db.Float)
    leaf_count = db.Column(db.Integer)
    potting_mix = db.Column(db.String(255))
    container_size = db.Column(db.String(120))
    health_status = db.Column(db.String(50))
    notes = db.Column(db.Text)

    # Image references via SubmissionImage table
    images = db.relationship('SubmissionImage', backref='submission', lazy=True)


class SubmissionImage(db.Model):
    __tablename__ = 'submission_images'

    id = db.Column(db.Integer, primary_key=True)
    submission_id = db.Column(db.Integer, db.ForeignKey('submissions.id'), nullable=False)
    file_path = db.Column(db.String(255), nullable=False)
    is_visible = db.Column(db.Boolean, default=True)
